@@ -1,5 +1,5 @@
 #
-# $Id: ETH.pm,v 1.2.2.30 2006/03/19 17:17:01 gomor Exp $
+# $Id: ETH.pm,v 1.2.2.31 2006/04/25 20:50:04 gomor Exp $
 #
 package Net::Packet::ETH;
 
@@ -24,7 +24,7 @@ our @AS = qw(
    type
 );
 
-__PACKAGE__->buildAccessorsScalar(\@AS);
+__PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
 sub new {
    my $self = shift->SUPER::new(
