@@ -1,5 +1,5 @@
 #
-# $Id: Layer7.pm,v 1.1.1.1.4.25 2006/03/19 17:17:01 gomor Exp $
+# $Id: Layer7.pm,v 1.1.1.1.4.26 2006/04/25 20:50:04 gomor Exp $
 #
 package Net::Packet::Layer7;
 
@@ -16,7 +16,7 @@ our @AS = qw(
    data
 );
 
-__PACKAGE__->buildAccessorsScalar(\@AS);
+__PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
 sub new { shift->SUPER::new(@_) }
 
