@@ -1,5 +1,5 @@
 #
-# $Id: VLAN.pm,v 1.1.2.7 2006/03/19 17:17:01 gomor Exp $
+# $Id: VLAN.pm,v 1.1.2.8 2006/04/25 20:50:04 gomor Exp $
 #
 package Net::Packet::VLAN;
 
@@ -22,7 +22,7 @@ our @AS = qw(
    frame
 );
 
-__PACKAGE__->buildAccessorsScalar(\@AS);
+__PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
 sub new {
    my $self = shift->SUPER::new(
